@@ -82,7 +82,14 @@ except FileNotFoundError:
         f.write('{\n}')
 
 
+# Set icon
+# https://stackoverflow.com/a/34547834
+import ctypes
+myappid = 'mycompany.myproduct.subproduct.version'
+ctypes.windll.shell32.SetCurrentProcessExplicitAppUserModelID(myappid)
 sg.set_global_icon(cfg['app-icon'])
+
+# Set GUI theme
 sg.theme_background_color(cfg['color-background'])
 sg.theme_element_background_color(cfg['color-background'])
 sg.theme_text_color(cfg['color-text'])
@@ -93,5 +100,6 @@ sg.theme_button_color(
     (cfg['color-button-text'], cfg['color-button-background']))
 sg.theme_border_width(cfg['control-border-width'])
 
+# Set locale
 CFG_APPNAME, CFG_SELECT_INFO, CFG_APPNAME_SES, CFG_GREET, CFG_CORRECT, CFG_INCORRECT, CFG_ADDWORD, CFG_NEWWORD, CFG_GUESS, CFG_TRANSLATE, CFG_TRANSLATE_OPENED, CFG_RESET, CFG_MENU, CFG_CONFIRM_DELETE, CFG_CONFIRM_RESET = cfg[
     'locale']
